@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.115 2000/07/27 22:05:08 nisse Exp $ */
+ * $Id: lsh.c,v 1.117 2000/09/03 21:47:39 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -35,6 +35,7 @@
 #include "compress.h"
 #include "connection_commands.h"
 #include "crypto.h"
+#include "dsa.h"
 #include "format.h"
 #include "interact.h"
 #include "io.h"
@@ -403,7 +404,7 @@ do_lsh_lookup(struct lookup_verifier *c,
       }
     case ATOM_SPKI:
       {
-	struct sexp *e = string_to_sexp(key, 0);
+	struct sexp *e = string_to_sexp(SEXP_CANONICAL, key, 0);
 	if (!e)
 	  {
 	    werror("do_lsh_lookup: Invalid spki s-expression.\n");
