@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.h,v 1.27 2000/05/28 00:25:28 nisse Exp $ */
+ * $Id: sexp.h,v 1.29 2000/09/03 17:22:14 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -156,7 +156,7 @@ struct lsh_string *sexp2string(struct sexp *e);
 int sexp2atom(struct sexp *e);
 
 int
-sexp2bignum_u(struct sexp *e, mpz_t n);
+sexp2bignum_u(struct sexp *e, mpz_t n, UINT32 limit);
 
 /* int sexp_null_cdr(struct sexp *e); */
 
@@ -188,7 +188,7 @@ int
 sexp_check_type(struct sexp *e, int type, struct sexp_iterator **res);
 
 
-int sexp_get_un(struct sexp_iterator *i, int atom, mpz_t n);
+int sexp_get_un(struct sexp_iterator *i, int atom, mpz_t n, UINT32 limit);
 
 extern int sexp_char_classes[];
 
@@ -199,7 +199,10 @@ struct sexp *
 sexp_parse_canonical(struct simple_buffer *buffer);
 
 struct sexp *
-string_to_sexp(struct lsh_string *src, int free);
+sexp_parse_transport(struct simple_buffer *buffer);
+
+struct sexp *
+string_to_sexp(int style, struct lsh_string *src, int free);
 
 
 /* Streamed parser */
