@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.c,v 1.47 2000/06/26 20:33:52 nisse Exp $ */
+ * $Id: werror.c,v 1.48 2000/07/27 21:52:26 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -108,16 +108,21 @@ static const struct exception *
 static const struct exception *
 write_syslog(int fd UNUSED, UINT32 length, const UINT8 *data)
 {
-  UINT8 string_buffer[BUF_SIZE];
-  
-  /* Make sure the message is properly terminated with \0. */
-  snprintf(string_buffer, (BUF_SIZE > length) ? BUF_SIZE : length, "%s", data);
+  struct lsh_string *s = make_cstring_l(length, data);
 
+  /* NOTE: make_cstring fails if the data contains any NUL characters. */
+  assert(s);
+
+#if 0
+  /* Make sure the message is properly terminated with \0. */
+  snprintf(string_buffer, MIN(BUF_SIZE, length), "%s", data);
+#endif
   /* FIXME: Should we use different log levels for werror, verbose and
    * debug? */
   
-  syslog(LOG_NOTICE, "%s", string_buffer);
-
+  syslog(LOG_NOTICE, "%s", s->data);
+  lsh_string_free(s);
+  
   return NULL;
 }
 
